<?php

namespace App\Application\Controller\Request\Manager;

use App\Application\Services\Request\GetRequestsService;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\Attribute\AsController;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\Security\Http\Attribute\IsGranted;
use Symfony\Component\Serializer\Normalizer\NormalizerInterface;

#[AsController]
final class GetRequestByIdController
{
    public function __construct(
        private readonly GetRequestsService $requestService,
        private readonly NormalizerInterface $normalizer
    ) {
    }

    #[Route('/api/requests/{requestId}', name: 'get_request_detail', methods: ['GET'])]
    #[IsGranted('ROLE_MANAGER')]
    public function __invoke(string $requestId): Response
    {
        $response = $this->requestService->get($requestId);

        if (!$response) {
            return new Response(status: Response::HTTP_NOT_FOUND);
        }

        return new JsonResponse($this->normalizer->normalize($response));
    }
}