<?php

namespace App\Application\Controller\Request\Manager;

use App\Application\Services\Request\GetRequestsService;
use App\Domain\Request\DTO\Request\Query\GetRequestsDTO;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\Attribute\AsController;
use Symfony\Component\HttpKernel\Attribute\MapQueryString;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\Security\Http\Attribute\IsGranted;
use Symfony\Component\Serializer\Normalizer\NormalizerInterface;

#[AsController]
final class GetRequestsController
{
    public function __construct(
        private readonly GetRequestsService $requestService,
        private readonly NormalizerInterface $normalizer
    ) {
    }

    #[Route('/api/requests', name: 'get_requests', methods: ['GET'])]
    #[IsGranted('ROLE_MANAGER')]
    public function __invoke(#[MapQueryString] ?GetRequestsDTO $query): Response
    {
        if (!$query) {
            $query = new GetRequestsDTO();
        }

        $response = $this->requestService->getAll($query);

        return new JsonResponse($this->normalizer->normalize($response));
    }
}