<?php

namespace App\Application\Controller\Request\Manager;

use App\Application\Services\Request\UpdateRequestService;
use App\Domain\Request\DTO\Request\Query\ChangeStatusRequestDTO;
use App\Domain\Request\Exception\NotAvailableStatusException;
use App\Domain\Request\Exception\RequestNotExistException;
use Symfony\Component\HttpFoundation\Exception\BadRequestException;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\Attribute\AsController;
use Symfony\Component\HttpKernel\Attribute\MapRequestPayload;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\Security\Http\Attribute\IsGranted;

#[AsController]
final class ManageRequestController
{
    public function __construct(
        private readonly UpdateRequestService $requestService,
    ) {
    }

    #[Route('/api/requests/{requestId}', name: 'update_request_detail', methods: ['PATCH'])]
    #[IsGranted('ROLE_MANAGER')]
    public function __invoke(string $requestId, #[MapRequestPayload] ChangeStatusRequestDTO $requestDTO): Response
    {
        try {
            $this->requestService->updateRequestStatus($requestId, $requestDTO);
        } catch (RequestNotExistException) {
            return new Response(status: Response::HTTP_NOT_FOUND);
        } catch (NotAvailableStatusException) {
            throw new BadRequestException('Невалидный статус запроса');
        }

        return new Response(status: Response::HTTP_NO_CONTENT);
    }
}