<?php

namespace App\Application\Controller\Request\User;

use App\Application\Services\Request\GetUserRequestService;
use App\Domain\Request\DTO\Request\Query\GetRequestsDTO;
use Doctrine\DBAL\Exception;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\Attribute\AsController;
use Symfony\Component\HttpKernel\Attribute\MapQueryString;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\Security\Http\Attribute\IsGranted;
use Symfony\Component\Serializer\Exception\ExceptionInterface;
use Symfony\Component\Serializer\Normalizer\NormalizerInterface;

#[AsController]
final class GetUserRequestsController
{
    public function __construct(
        private readonly GetUserRequestService $requestService,
        private readonly NormalizerInterface $normalizer
    ) {
    }

    #[Route('/api/user/requests', name: 'get_user_requests', methods: ['GET'])]
    #[IsGranted('ROLE_USER')]
    public function __invoke(#[MapQueryString] ?GetRequestsDTO $query): Response
    {
        if (!$query) {
            $query = new GetRequestsDTO();
        }

        $response = $this->requestService->getAll($query);

        return new JsonResponse($this->normalizer->normalize($response));
    }
}
