<?php

namespace App\Application\DataFixtures;

use App\Domain\User\Entity\Role;
use App\Domain\User\Entity\User;
use App\Domain\User\Enums\RoleCodes;
use Doctrine\Bundle\FixturesBundle\Fixture;
use Doctrine\Persistence\ObjectManager;
use Symfony\Component\PasswordHasher\Hasher\UserPasswordHasherInterface;

class UserFixtures extends Fixture
{
    private const USER_PASSWORD = 'password';

    public function __construct(private readonly UserPasswordHasherInterface $hasher)
    {
    }

    public function load(ObjectManager $manager): void
    {
        $userRole = new Role(RoleCodes::BASIC_USER);
        $manager->persist($userRole);

        $managerRole = new Role(RoleCodes::MANAGER);
        $manager->persist($managerRole);

        $basicUser = new User('test@gmail.com', self::USER_PASSWORD, $userRole);
        $hashedPassword = $this->hasher->hashPassword($basicUser, self::USER_PASSWORD);
        $basicUser->setPassword($hashedPassword);
        $manager->persist($basicUser);

        $managerUser = new User('testAdmin@gmail.com', self::USER_PASSWORD, $managerRole);
        $hashedPassword = $this->hasher->hashPassword($managerUser, self::USER_PASSWORD);
        $managerUser->setPassword($hashedPassword);
        $manager->persist($managerUser);

        $manager->flush();
    }
}
