<?php

namespace App\Application\Services\Request;

use App\Domain\Request\DTO\PaginationDataDTO;
use App\Domain\Request\DTO\Request\Query\GetRequestsDTO;
use App\Domain\Request\DTO\Request\Response\RequestDTO;
use App\Domain\Request\Interfaces\RequestReaderInterface;
use Doctrine\DBAL\Exception;

final class GetRequestsService
{
    public function __construct(
        private readonly RequestReaderInterface $reader,
    ) {
    }

    /**
     * Список запросов
     *
     * @param GetRequestsDTO $query
     * @return PaginationDataDTO
     */
    public function getAll(GetRequestsDTO $query): PaginationDataDTO
    {
        return $this->reader->getRequests($query);
    }

    /**
     * Запрос по его идентификатору
     *
     * @param string $requestId
     * @return RequestDTO|null
     */
    public function get(string $requestId): ?RequestDTO
    {
        return $this->reader->getRequestById($requestId);
    }
}