<?php

namespace App\Application\Services\Request;

use App\Domain\Request\DTO\PaginationDataDTO;
use App\Domain\Request\DTO\Request\Query\GetRequestsDTO;
use App\Domain\Request\DTO\Request\Response\RequestDTO;
use App\Domain\Request\Interfaces\RequestReaderInterface;
use Doctrine\DBAL\Exception;
use Symfony\Component\Security\Core\Authentication\Token\Storage\TokenStorageInterface;

final class GetUserRequestService
{
    public function __construct(
        private readonly RequestReaderInterface $repository,
        private readonly TokenStorageInterface $token,
    ) {
    }

    /**
     * Список запросов, созданных пользователем
     *
     * @param GetRequestsDTO $query
     * @return PaginationDataDTO
     * @throws Exception
     */
    public function getAll(GetRequestsDTO $query): PaginationDataDTO
    {
        $query->userId = $this->token->getToken()->getUser()->getUuid();

        return $this->repository->getRequests($query);
    }

    /**
     * Запрос по его идентификатору
     *
     * @param string $requestId
     * @return RequestDTO|null
     */
    public function get(string $requestId): ?RequestDTO
    {
        $userId = $this->token->getToken()->getUser()->getUuid();

        return $this->repository->getRequestById($requestId, $userId);
    }
}
