<?php

namespace App\Application\Services\Request;

use App\Domain\Request\DTO\Request\Query\ChangeStatusRequestDTO;
use App\Domain\Request\Exception\NotAvailableStatusException;
use App\Domain\Request\Exception\RequestNotExistException;
use App\Domain\Request\Interfaces\RequestRepositoryInterface;
use App\Domain\Request\Status\Status;

final class UpdateRequestService
{
    public function __construct(
        private readonly RequestRepositoryInterface $repository,
    ) {
    }

    /**
     * Обновить статус запроса
     *
     * @param string $id
     * @param ChangeStatusRequestDTO $requestDTO
     * @return void
     * @throws RequestNotExistException
     * @throws NotAvailableStatusException
     */
    public function updateRequestStatus(string $id, ChangeStatusRequestDTO $requestDTO): void
    {
        $request = $this->repository->getById($id);

        if ($request === null) {
            throw new RequestNotExistException();
        }

        $status = Status::tryFrom($requestDTO->status);

        if ($status === null) {
            throw new NotAvailableStatusException();
        }

        $request->setNewStatus($status, $requestDTO->comment);

        $this->repository->persist($request);
    }
}