<?php

namespace App\Domain\User\Entity;

use App\Domain\User\Enums\RoleCodes;
use Doctrine\ORM\Mapping\Column;
use Doctrine\ORM\Mapping\Entity;
use Doctrine\ORM\Mapping\GeneratedValue;
use Doctrine\ORM\Mapping\Id;
use Doctrine\ORM\Mapping\SequenceGenerator;
use Doctrine\ORM\Mapping\Table;

#[Entity]
#[Table(name: 'roles')]
class Role
{
    #[Id]
    #[Column(type: 'integer', options: [
        'default' => 'nextval(\'role_id\')'
    ])]
    #[GeneratedValue(strategy: 'SEQUENCE')]
    #[SequenceGenerator(sequenceName: 'role_id', initialValue: 1)]
    private ?int $id = null;

    /**
     * Класс, описывающий Роль пользователя
     *
     * @param RoleCodes $code
     */
    public function __construct(
        #[Column(name: 'code', type: 'string', unique: true, enumType: RoleCodes::class)]
        private RoleCodes $code
    ) {
    }

    /**
     * Код роли
     *
     * @return RoleCodes
     */
    public function getRoleCode(): RoleCodes
    {
        return $this->code;
    }

    /**
     * Идентификатор
     *
     * @return int|null
     */
    public function getId(): ?int
    {
        return  $this->id;
    }
}
