<?php

namespace Request\Entity;

use App\Domain\Request\DTO\Request\Query\NewRequestDTO;
use App\Domain\Request\Entity\Request;
use App\Domain\Request\Status\Status;
use PHPUnit\Framework\TestCase;
use Ramsey\Uuid\Uuid;

class RequestTest extends TestCase
{
    public function testCannotBeCreatedWithoutTopic()
    {
        $this->expectException(\InvalidArgumentException::class);

        $mockUserId = Uuid::uuid4()->toString();

        $requestNew = new NewRequestDTO('', 'some message');

        Request::create($requestNew, $mockUserId);
    }

    public function testCannotBeCreatedWithoutMessage()
    {
        $this->expectException(\InvalidArgumentException::class);

        $mockUserId = Uuid::uuid4()->toString();

        $requestNew = new NewRequestDTO('some topic', '');

        Request::create($requestNew, $mockUserId);
    }

    public function testCannotBeUpdatedStatusWithoutComment()
    {
        $this->expectException(\InvalidArgumentException::class);

        $mockUserId = Uuid::uuid4()->toString();
        $requestNew = new NewRequestDTO('some topic', 'some message');

        $request = Request::create($requestNew, $mockUserId);

        $request->setNewStatus(Status::IN_PROGRESS, '');
    }

    public function testCanBeUpdatedStatusWithComment()
    {
        $comment = 'Чек';

        $mockUserId = Uuid::uuid4()->toString();
        $requestNew = new NewRequestDTO('some topic', 'some message');

        $request = Request::create($requestNew, $mockUserId);

        $request->setNewStatus(Status::IN_PROGRESS, $comment);

        $this->assertSame($comment, $request->getComment());
        $this->assertSame(Status::IN_PROGRESS, $request->getStatus());
    }
}